# Generated by Django 4.0.5 on 2022-06-17 10:13

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('django_tenants', '0004_alter_tenant_slug'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='tenant',
            name='description',
        ),
        migrations.RemoveField(
            model_name='tenant',
            name='name',
        ),
    ]
